@@ -5,6 +5,8 @@ from xml.etree import ElementTree
 import html
 from wand.image import Image
 from wand.exceptions import PolicyError, WandRuntimeError
+from elifearticle import parse as articleparse
+from elifetools.utils import escape_ampersand
 from elifecleaner import LOGGER, pdf_utils, utils, zip_lib
 
 
@@ -15,6 +17,11 @@ REPAIR_XML = True
 ART_FILE_EXTENSIONS = ["doc", "docx", "tex"]
 
 
+def article_from_xml(xml_file_path):
+    "parse using elifearticle library into an Article object"
+    return articleparse.build_article_from_xml(xml_file_path)
+
+
 def check_ejp_zip(zip_file, tmp_dir):
     "check contents of ejp zip file"
     asset_file_name_map = zip_lib.unzip_zip(zip_file, tmp_dir)
@@ -299,6 +306,8 @@ def parse_article_xml(xml_file):
             return ElementTree.fromstring(xml_string)
         except ElementTree.ParseError:
             if REPAIR_XML:
+                # fix ampersands
+                xml_string = escape_ampersand(xml_string)
                 # try to repair the xml namespaces
                 xml_string = repair_article_xml(xml_string)
                 return ElementTree.fromstring(xml_string)
